@@ -11,6 +11,7 @@ from ecowitt2mqtt.const import (
     CONF_CONFIG,
     CONF_DEFAULT_BATTERY_STRATEGY,
     CONF_DIAGNOSTICS,
+    CONF_DISABLE_CALCULATED_DATA,
     CONF_ENDPOINT,
     CONF_HASS_DISCOVERY,
     CONF_HASS_DISCOVERY_PREFIX,
@@ -19,6 +20,7 @@ from ecowitt2mqtt.const import (
     CONF_MQTT_BROKER,
     CONF_MQTT_PASSWORD,
     CONF_MQTT_PORT,
+    CONF_MQTT_RETAIN,
     CONF_MQTT_TLS,
     CONF_MQTT_TOPIC,
     CONF_MQTT_USERNAME,
@@ -182,7 +184,12 @@ class Config:
     @property
     def diagnostics(self) -> bool:
         """Return whether diagnostics is enabled."""
-        return cast(bool, self._config.get(CONF_DIAGNOSTICS))
+        return cast(bool, self._config.get(CONF_DIAGNOSTICS, False))
+
+    @property
+    def disable_calculated_data(self) -> bool:
+        """Return whether calculated sensor output is disabled."""
+        return cast(bool, self._config.get(CONF_DISABLE_CALCULATED_DATA, False))
 
     @property
     def endpoint(self) -> str:
@@ -192,7 +199,7 @@ class Config:
     @property
     def hass_discovery(self) -> bool:
         """Return whether Home Assistant Discovery should be used."""
-        return cast(bool, self._config.get(CONF_HASS_DISCOVERY))
+        return cast(bool, self._config.get(CONF_HASS_DISCOVERY, False))
 
     @property
     def hass_discovery_prefix(self) -> str:
@@ -224,10 +231,15 @@ class Config:
         """Return the MQTT broker port."""
         return cast(int, self._config.get(CONF_MQTT_PORT))
 
+    @property
+    def mqtt_retain(self) -> bool:
+        """Return whether MQTT messages should be retained."""
+        return cast(bool, self._config.get(CONF_MQTT_RETAIN, False))
+
     @property
     def mqtt_tls(self) -> bool:
         """Return whether MQTT over TLS is configured."""
-        return cast(bool, self._config.get(CONF_MQTT_TLS))
+        return cast(bool, self._config.get(CONF_MQTT_TLS, False))
 
     @property
     def mqtt_topic(self) -> str | None:
@@ -252,9 +264,9 @@ class Config:
     @property
     def raw_data(self) -> bool:
         """Return whether raw data is configured."""
-        return cast(bool, self._config.get(CONF_RAW_DATA))
+        return cast(bool, self._config.get(CONF_RAW_DATA, False))
 
     @property
     def verbose(self) -> bool:
         """Return whether verbose logging is enabled."""
-        return cast(bool, self._config.get(CONF_VERBOSE))
+        return cast(bool, self._config.get(CONF_VERBOSE, False))
