@@ -6,9 +6,14 @@ import os
 from typing import Any
 
 from ecowitt2mqtt.config import Config
-from ecowitt2mqtt.const import CONF_VERBOSE, LEGACY_ENV_LOG_LEVEL, LOGGER
+from ecowitt2mqtt.const import (
+    CONF_VERBOSE,
+    LEGACY_ENV_LOG_LEVEL,
+    LOGGER,
+    __version__ as ecowitt2mqtt_version,
+)
 from ecowitt2mqtt.helpers.logging import TyperLoggerHandler
-from ecowitt2mqtt.server import Server
+from ecowitt2mqtt.runtime import Runtime
 
 
 class Ecowitt:  # pylint: disable=too-few-public-methods
@@ -27,10 +32,15 @@ class Ecowitt:  # pylint: disable=too-few-public-methods
             handlers=(TyperLoggerHandler(),),
         )
 
-        self.config = Config(params)
-        self.server = Server(self)
+        self._config = Config(params)
+        self._runtime = Runtime(self)
+
+    @property
+    def config(self) -> Config:
+        """Return the config object."""
+        return self._config
 
     async def async_start(self) -> None:
         """Start ecowitt2mqtt."""
-        LOGGER.info("Starting ecowitt2mqtt")
-        await self.server.async_start()
+        LOGGER.info("Starting ecowitt2mqtt (version %s)", ecowitt2mqtt_version)
+        await self._runtime.async_start()
