@@ -78,14 +78,202 @@ WIND_SPEED_UNIT_MAP = {
     UNIT_SYSTEM_METRIC: SPEED_KILOMETERS_PER_HOUR,
 }
 
-SAFE_EXPOSURE_CONSTANT_MAP: dict[str, float] = {
-    DATA_POINT_SAFE_EXPOSURE_TIME_SKIN_TYPE_1: 2.5,
-    DATA_POINT_SAFE_EXPOSURE_TIME_SKIN_TYPE_2: 3.0,
-    DATA_POINT_SAFE_EXPOSURE_TIME_SKIN_TYPE_3: 4.0,
-    DATA_POINT_SAFE_EXPOSURE_TIME_SKIN_TYPE_4: 5.0,
-    DATA_POINT_SAFE_EXPOSURE_TIME_SKIN_TYPE_5: 8.0,
-    DATA_POINT_SAFE_EXPOSURE_TIME_SKIN_TYPE_6: 13.0,
-}
+
+@dataclass
+class BeaufortScaleRating:  # pylint: disable=too-many-instance-attributes
+    """Define a dataclass to store a Beaufort scale rating."""
+
+    number: int
+    minimum_kmh: float
+    maximum_kmh: float
+    minimum_mph: float
+    maximum_mph: float
+    description: str
+    sea_conditions: str
+    land_conditions: str
+
+
+BEAUFORT_SCALE_RATINGS: list[BeaufortScaleRating] = [
+    BeaufortScaleRating(
+        number=0,
+        minimum_kmh=0.0,
+        maximum_kmh=2.0,
+        minimum_mph=0.0,
+        maximum_mph=1.0,
+        description="Calm",
+        sea_conditions="Sea like a mirror",
+        land_conditions="Smoke rises vertically",
+    ),
+    BeaufortScaleRating(
+        number=1,
+        minimum_kmh=2.0,
+        maximum_kmh=6.0,
+        minimum_mph=1.0,
+        maximum_mph=4.0,
+        description="Light air",
+        sea_conditions=(
+            "Ripples with appearance of scales are formed, without foam crests"
+        ),
+        land_conditions="Direction shown by smoke drift but not by wind vanes",
+    ),
+    BeaufortScaleRating(
+        number=2,
+        minimum_kmh=6.0,
+        maximum_kmh=12.0,
+        minimum_mph=4.0,
+        maximum_mph=8.0,
+        description="Light breeze",
+        sea_conditions=(
+            "Small wavelets still short but more pronounced; crests have a glassy "
+            "appearance but do not break"
+        ),
+        land_conditions="Wind felt on face; leaves rustle; wind vane moved by wind",
+    ),
+    BeaufortScaleRating(
+        number=3,
+        minimum_kmh=12.0,
+        maximum_kmh=20.0,
+        minimum_mph=8.0,
+        maximum_mph=13.0,
+        description="Gentle breeze",
+        sea_conditions=(
+            "Large wavelets; crests begin to break; foam of glassy appearance; perhaps "
+            "scattered white horses"
+        ),
+        land_conditions=(
+            "Leaves and small twigs in constant motion; light flags extended"
+        ),
+    ),
+    BeaufortScaleRating(
+        number=4,
+        minimum_kmh=20.0,
+        maximum_kmh=29.0,
+        minimum_mph=13.0,
+        maximum_mph=19.0,
+        description="Moderate breeze",
+        sea_conditions="Small waves becoming longer; fairly frequent white horses",
+        land_conditions="Raises dust and loose paper; small branches moved",
+    ),
+    BeaufortScaleRating(
+        number=5,
+        minimum_kmh=29.0,
+        maximum_kmh=39.0,
+        minimum_mph=19.0,
+        maximum_mph=25.0,
+        description="Fresh breeze",
+        sea_conditions=(
+            "Moderate waves taking a more pronounced long form; many white horses are "
+            "formed; chance of some spray"
+        ),
+        land_conditions=(
+            "Small trees in leaf begin to sway; crested wavelets form on inland waters"
+        ),
+    ),
+    BeaufortScaleRating(
+        number=6,
+        minimum_kmh=39.0,
+        maximum_kmh=50.0,
+        minimum_mph=25.0,
+        maximum_mph=32.0,
+        description="Strong breeze",
+        sea_conditions=(
+            "Large waves begin to form; the white foam crests are more "
+            "extensive everywhere; probably some spray"
+        ),
+        land_conditions=(
+            "Large branches in motion; whistling heard in telegraph wires; "
+            "umbrellas used with difficulty"
+        ),
+    ),
+    BeaufortScaleRating(
+        number=7,
+        minimum_kmh=50.0,
+        maximum_kmh=62.0,
+        minimum_mph=32.0,
+        maximum_mph=39.0,
+        description="High wind, moderate gale, near gale",
+        sea_conditions=(
+            "Sea heaps up and white foam from breaking waves begins to be "
+            "blown in streaks along the direction of the wind; spindrift begins to be "
+            "seen"
+        ),
+        land_conditions=(
+            "Whole trees in motion; inconvenience felt when walking against the wind"
+        ),
+    ),
+    BeaufortScaleRating(
+        number=8,
+        minimum_kmh=62.0,
+        maximum_kmh=75.0,
+        minimum_mph=39.0,
+        maximum_mph=47.0,
+        description="Gale, fresh gale",
+        sea_conditions=(
+            "Moderately high waves of greater length; edges of crests break into "
+            "spindrift; foam is blown in well-marked streaks along the direction of "
+            "the wind"
+        ),
+        land_conditions=("Twigs break off trees; generally impedes progress"),
+    ),
+    BeaufortScaleRating(
+        number=9,
+        minimum_kmh=75.0,
+        maximum_kmh=89.0,
+        minimum_mph=47.0,
+        maximum_mph=55.0,
+        description="Strong/severe gale",
+        sea_conditions=(
+            "High waves; dense streaks of foam along the direction of the "
+            "wind; sea begins to roll; spray affects visibility"
+        ),
+        land_conditions="Slight structural damage (chimney pots and slates removed)",
+    ),
+    BeaufortScaleRating(
+        number=10,
+        minimum_kmh=89.0,
+        maximum_kmh=103.0,
+        minimum_mph=55.0,
+        maximum_mph=64.0,
+        description="Storm, whole gale",
+        sea_conditions=(
+            "Very high waves with long overhanging crests; resulting foam in great "
+            "patches is blown in dense white streaks along the direction of the wind; "
+            "on the whole the surface of the sea takes on a white appearance; rolling "
+            "of the sea becomes heavy; visibility affected"
+        ),
+        land_conditions=(
+            "Seldom experienced inland; trees uprooted; considerable structural damage"
+        ),
+    ),
+    BeaufortScaleRating(
+        number=11,
+        minimum_kmh=103.0,
+        maximum_kmh=118.0,
+        minimum_mph=64.0,
+        maximum_mph=73.0,
+        description="Violent storm",
+        sea_conditions=(
+            "Exceptionally high waves; small- and medium-sized ships might be for a "
+            "long time lost to view behind the waves; sea is covered with long white "
+            "patches of foam; everywhere the edges of the wave crests are blown into "
+            "foam; visibility affected"
+        ),
+        land_conditions="Very rarely experienced; accompanied by widespread damage",
+    ),
+    BeaufortScaleRating(
+        number=12,
+        minimum_kmh=118.0,
+        maximum_kmh=300.0,
+        minimum_mph=73.0,
+        maximum_mph=200.0,
+        description="Hurricane force",
+        sea_conditions=(
+            "The air is filled with foam and spray; sea is completely white with "
+            "driving spray; visibility very seriously affected"
+        ),
+        land_conditions="Devastation",
+    ),
+]
 
 
 class FrostRisk(StrEnum):
@@ -97,6 +285,66 @@ class FrostRisk(StrEnum):
     VERY_PROBABLE = "Very probable"
 
 
+@dataclass
+class SafeExposureInfo:
+    """Define a dataclass to store information about a safe exposure level."""
+
+    constant: float
+    typical_features: str
+    tanning_ability: str
+    ethnicity: str
+
+
+SAFE_EXPOSURE_INFO_MAP: dict[str, SafeExposureInfo] = {
+    DATA_POINT_SAFE_EXPOSURE_TIME_SKIN_TYPE_1: SafeExposureInfo(
+        constant=2.5,
+        ethnicity="Scandinavian, Celtic",
+        tanning_ability="Always burns, does not tan",
+        typical_features=(
+            "Very fair skin, white; red or blond hair; light-colored eyes; freckles "
+            "likely"
+        ),
+    ),
+    DATA_POINT_SAFE_EXPOSURE_TIME_SKIN_TYPE_2: SafeExposureInfo(
+        constant=3.0,
+        ethnicity="Northern European (Caucasian)",
+        tanning_ability="Burns easily, tans poorly",
+        typical_features="Fair skin, white; light eyes; light hair",
+    ),
+    DATA_POINT_SAFE_EXPOSURE_TIME_SKIN_TYPE_3: SafeExposureInfo(
+        constant=4.0,
+        ethnicity="Darker Caucasian (Central Europe)",
+        tanning_ability="Tans after initial burn",
+        typical_features=(
+            "Fair skin, cream white; any eye or hair color (very common skin type)"
+        ),
+    ),
+    DATA_POINT_SAFE_EXPOSURE_TIME_SKIN_TYPE_4: SafeExposureInfo(
+        constant=5.0,
+        ethnicity="Mediterranean, Asian, Hispanic",
+        tanning_ability="Burns minimally, tans easily",
+        typical_features=(
+            "Olive skin, typical Mediterranean Caucasian skin; dark brown hair; medium "
+            "to heavy pigmentation"
+        ),
+    ),
+    DATA_POINT_SAFE_EXPOSURE_TIME_SKIN_TYPE_5: SafeExposureInfo(
+        constant=8.0,
+        ethnicity="Middle eastern, Latin, light-skinned African-American, Indian",
+        tanning_ability="Rarely burns, tans darkly easily",
+        typical_features=(
+            "Brown skin, typical Middle Eastern skin; dark hair; rarely sun sensitive"
+        ),
+    ),
+    DATA_POINT_SAFE_EXPOSURE_TIME_SKIN_TYPE_6: SafeExposureInfo(
+        constant=13.0,
+        ethnicity="Dark-skinned African American",
+        tanning_ability="Never burns, always tans darkly",
+        typical_features="Black skin; rarely sun sensitive",
+    ),
+}
+
+
 class SimmerZone(StrEnum):
     """Define types of simmer zone."""
 
@@ -119,28 +367,6 @@ class SimmerZoneRating:
     maximum_f: float | None = None
 
 
-class ThermalPerception(StrEnum):
-    """Define types of thermal perception."""
-
-    COMFORTABLE = "Comfortable"
-    DRY = "Dry"
-    EXTREMELY_UNCOMFORTABLE = "Extremely uncomfortable"
-    OK_BUT_HUMID = "OK for most"
-    QUITE_UNCOMFORTABLE = "Quite uncomfortable"
-    SEVERELY_HIGH = "Severely high"
-    SOMEWHAT_UNCOMFORTABLE = "Somewhat uncomfortable"
-    VERY_COMFORTABLE = "Very comfortable"
-
-
-@dataclass
-class ThermalPerceptionRating:
-    """Define a dataclass to store a thermal perception rating."""
-
-    perception: ThermalPerception
-    minimum_c: float
-    maximum_c: float
-
-
 SIMMER_ZONE_RATINGS: list[SimmerZoneRating] = [
     SimmerZoneRating(
         zone=SimmerZone.SLIGHTLY_COOL,
@@ -185,6 +411,28 @@ SIMMER_ZONE_RATINGS: list[SimmerZoneRating] = [
 ]
 
 
+class ThermalPerception(StrEnum):
+    """Define types of thermal perception."""
+
+    COMFORTABLE = "Comfortable"
+    DRY = "Dry"
+    EXTREMELY_UNCOMFORTABLE = "Extremely uncomfortable"
+    OK_BUT_HUMID = "OK for most"
+    QUITE_UNCOMFORTABLE = "Quite uncomfortable"
+    SEVERELY_HIGH = "Severely high"
+    SOMEWHAT_UNCOMFORTABLE = "Somewhat uncomfortable"
+    VERY_COMFORTABLE = "Very comfortable"
+
+
+@dataclass
+class ThermalPerceptionRating:
+    """Define a dataclass to store a thermal perception rating."""
+
+    perception: ThermalPerception
+    minimum_c: float
+    maximum_c: float
+
+
 THERMAL_PERCEPTION_RATINGS: list[ThermalPerceptionRating] = [
     ThermalPerceptionRating(
         perception=ThermalPerception.SEVERELY_HIGH,
@@ -274,7 +522,10 @@ def _get_simmer_index_object(
 ) -> meteocalc.Temp | None:
     """Get a simmer index object."""
     if temp_obj.f < 70:
-        return None
+        raise ValueError(
+            "Simmer Index is only valid for temperatures above 70°F (21.1 °C)"
+        )
+
     return _get_temperature_object(
         (
             1.98
@@ -317,6 +568,37 @@ def calculate_absolute_humidity(
     )
 
 
+def calculate_beaufort_scale(
+    ecowitt: Ecowitt,
+    payload_key: str,
+    data_point_key: str,
+    wind_speed: float,
+) -> CalculatedDataPoint:
+    """Calculate the Beaufort Scale of a wind speed."""
+    [rating] = [
+        r
+        for r in BEAUFORT_SCALE_RATINGS
+        if (
+            ecowitt.config.input_unit_system == UNIT_SYSTEM_IMPERIAL
+            and r.minimum_mph <= wind_speed <= r.maximum_mph
+        )
+        or (
+            ecowitt.config.input_unit_system == UNIT_SYSTEM_METRIC
+            and r.minimum_kmh <= wind_speed <= r.maximum_kmh
+        )
+    ]
+
+    return CalculatedDataPoint(
+        data_point_key=data_point_key,
+        value=rating.number,
+        attributes={
+            "description": rating.description,
+            "sea_conditions": rating.sea_conditions,
+            "land_conditions": rating.land_conditions,
+        },
+    )
+
+
 def calculate_co2(
     ecowitt: Ecowitt, payload_key: str, data_point_key: str, value: float
 ) -> CalculatedDataPoint:
@@ -565,15 +847,24 @@ def calculate_safe_exposure_time(
     ecowitt: Ecowitt, payload_key: str, data_point_key: str, value: float
 ) -> CalculatedDataPoint:
     """Calculate the number of minutes one can be safely exposed to a UV index."""
+    safe_exposure_info = SAFE_EXPOSURE_INFO_MAP[payload_key]
+
     try:
-        final_value = round(
-            (200 * SAFE_EXPOSURE_CONSTANT_MAP[payload_key]) / (3 * value), 1
-        )
+        final_value = round((200 * safe_exposure_info.constant) / (3 * value), 1)
     except ZeroDivisionError:
-        final_value = None
+        return CalculatedDataPoint(
+            data_point_key=data_point_key, value=None, unit=TIME_MINUTES
+        )
 
     return CalculatedDataPoint(
-        data_point_key=data_point_key, value=final_value, unit=TIME_MINUTES
+        data_point_key=data_point_key,
+        value=final_value,
+        unit=TIME_MINUTES,
+        attributes={
+            "ethnicity": safe_exposure_info.ethnicity,
+            "tanning_ability": safe_exposure_info.tanning_ability,
+            "typical_features": safe_exposure_info.typical_features,
+        },
     )
 
 
@@ -586,19 +877,18 @@ def calculate_simmer_index(
 ) -> CalculatedDataPoint:
     """Calculate simmer index in the appropriate unit system."""
     temp_obj = _get_temperature_object(temperature, ecowitt.config.input_unit_system)
-    simmer_obj = _get_simmer_index_object(temp_obj, relative_humidity)
 
-    if simmer_obj:
+    try:
+        simmer_obj = _get_simmer_index_object(temp_obj, relative_humidity)
+    except ValueError as err:
+        LOGGER.debug("%s (temperature: %s)", err, temp_obj)
+        final_value = None
+    else:
+        assert simmer_obj
         if ecowitt.config.output_unit_system == UNIT_SYSTEM_IMPERIAL:
             final_value = round(simmer_obj.f, 1)
         else:
             final_value = round(simmer_obj.c, 1)
-    else:
-        LOGGER.debug(
-            "Simmer index is undefined for temperatures below 70°F (temperature: %s°F",
-            temp_obj.f,
-        )
-        final_value = None
 
     return CalculatedDataPoint(
         data_point_key=data_point_key,
@@ -616,19 +906,18 @@ def calculate_simmer_zone(
 ) -> CalculatedDataPoint:
     """Calculate the human perception of comfort level related to temperature."""
     temp_obj = _get_temperature_object(temperature, ecowitt.config.input_unit_system)
-    simmer_obj = _get_simmer_index_object(temp_obj, relative_humidity)
 
-    if simmer_obj:
+    try:
+        simmer_obj = _get_simmer_index_object(temp_obj, relative_humidity)
+    except ValueError as err:
+        LOGGER.debug("%s (temperature: %s)", err, temp_obj)
+        final_value = None
+    else:
+        assert simmer_obj
         [rating] = [
             r for r in SIMMER_ZONE_RATINGS if r.minimum_f <= simmer_obj.f <= r.maximum_f
         ]
         final_value = rating.zone
-    else:
-        LOGGER.debug(
-            "Simmer index is undefined for temperatures below 70°F (temperature: %s°F",
-            temp_obj.f,
-        )
-        final_value = None
 
     return CalculatedDataPoint(data_point_key=data_point_key, value=final_value)
 
